@@ -3,7 +3,7 @@
 import sys, os, tempfile, psycopg2
 
 if len(sys.argv) != 3:
-    print 'usage: mkauth DSTFN CONNSTR'
+    print('usage: mkauth DSTFN CONNSTR')
     sys.exit(1)
 
 # read old file
@@ -33,4 +33,3 @@ if old != cur:
     f.write(cur)
     f.close()
     os.rename(tmpfn, fn)
-
