@@ -18,8 +18,6 @@
 
 #include <usual/pgsocket.h>
 
-#include <stdarg.h>
-
 #include <usual/event.h>
 #include <usual/logging.h>
 #include <usual/time.h>
@@ -43,7 +41,8 @@ struct PgSocket {
 	/* track wait state */
 	enum WType wait_type;
 
-	uint8_t wait_event; // EV_READ / EV_WRITE
+	/* EV_READ / EV_WRITE */
+	uint8_t wait_event;
 
 	/* should connect after sleep */
 	bool reconnect;
@@ -406,4 +405,3 @@ bool pgs_waiting_for_reply(struct PgSocket *db)
 		return false;
 	return (db->wait_type == W_SOCK) && (db->wait_event == EV_READ);
 }
-
