@@ -1,10 +1,10 @@
 /*
  * Copyright (c) 2007-2009  Marko Kreen, Skype Technologies OÜ
- * 
+ *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * copyright notice and this permission notice appear in all copies.
- * 
+ *
  * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
@@ -54,6 +54,12 @@ const char *strlist_pop(struct StrList *slist);
 /** Parse comma-separated elements from string and launch callback for each of them. */
 bool parse_word_list(const char *s, str_cb cb_func, void *cb_arg);
 
+#ifndef HAVE_STRNLEN
+#define strnlen(a,b) usual_strnlen(a,b)
+/** Compat: determine the length of a fixed-size string */
+size_t strnlen(const char *string, size_t maxlen);
+#endif
+
 #ifndef HAVE_STRLCPY
 #define strlcpy(a,b,c) usual_strlcpy(a,b,c)
 /** Compat: Safely copy string to fixed-length buffer.  */
@@ -200,4 +206,3 @@ int vasprintf(char **dst_p, const char *fmt, va_list ap) _PRINTF(2, 0);
 #endif
 
 #endif
-
