@@ -1,12 +1,12 @@
 /*
  * PgBouncer - Lightweight connection pooler for PostgreSQL.
- * 
+ *
  * Copyright (c) 2007-2009  Marko Kreen, Skype Technologies OÜ
- * 
+ *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * copyright notice and this permission notice appear in all copies.
- * 
+ *
  * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
@@ -154,7 +154,7 @@ static void launch_recheck(PgPool *pool)
 
 	if (need_check) {
 		/* send test query, wait for result */
-		slog_debug(server, "P: Checking: %s", q);
+		slog_debug(server, "P: checking: %s", q);
 		change_server_state(server, SV_TESTED);
 		SEND_generic(res, server, 'Q', "s", q);
 		if (!res)
@@ -253,6 +253,43 @@ static int per_loop_suspend(PgPool *pool, bool force_suspend)
 	return active;
 }
 
+/*
+ * Count the servers in server_list that have close_needed set.
+ */
+static int count_close_needed(struct StatList *server_list)
+{
+	struct List *item;
+	PgSocket *server;
+	int count = 0;
+
+	statlist_for_each(item, server_list) {
+		server = container_of(item, PgSocket, head);
+		if (server->close_needed)
+			count++;
+	}
+
+	return count;
+}
+
+/*
+ * Per-loop tasks for WAIT_CLOSE
+ */
+static int per_loop_wait_close(PgPool *pool)
+{
+	int count = 0;
+
+	if (pool->db->admin)
+		return 0;
+
+	count += count_close_needed(&pool->active_server_list);
+	count += count_close_needed(&pool->idle_server_list);
+	count += count_close_needed(&pool->new_server_list);
+	count += count_close_needed(&pool->tested_server_list);
+	count += count_close_needed(&pool->used_server_list);
+
+	return count;
+}
+
 /*
  * this function is called for each event loop.
  */
@@ -261,7 +298,9 @@ void per_loop_maint(void)
 	struct List *item;
 	PgPool *pool;
 	int active = 0;
+	int waiting_count = 0;
 	int partial_pause = 0;
+	int partial_wait = 0;
 	bool force_suspend = false;
 
 	if (cf_pause_mode == P_SUSPEND && cf_suspend_timeout > 0) {
@@ -290,6 +329,11 @@ void per_loop_maint(void)
 			active += per_loop_suspend(pool, force_suspend);
 			break;
 		}
+
+		if (pool->db->db_wait_close) {
+			partial_wait = 1;
+			waiting_count += per_loop_wait_close(pool);
+		}
 	}
 
 	switch (cf_pause_mode) {
@@ -299,6 +343,7 @@ void per_loop_maint(void)
 		} else {
 			active += statlist_count(&login_client_list);
 		}
+		/* fallthrough */
 	case P_PAUSE:
 		if (!active)
 			admin_pause_done();
@@ -308,6 +353,9 @@ void per_loop_maint(void)
 			admin_pause_done();
 		break;
 	}
+
+	if (partial_wait && !waiting_count)
+		admin_wait_close_done();
 }
 
 /* maintaining clients in pool */
@@ -439,7 +487,7 @@ static void check_pool_size(PgPool *pool)
 	    cf_reboot == 0 &&
 	    pool_client_count(pool) > 0)
 	{
-		log_debug("Launching new connection to satisfy min_pool_size");
+		log_debug("launching new connection to satisfy min_pool_size");
 		launch_new_connection(pool);
 	}
 }
@@ -456,6 +504,16 @@ static void pool_server_maint(PgPool *pool)
 	check_unused_servers(pool, &pool->tested_server_list, 0);
 	check_unused_servers(pool, &pool->idle_server_list, 1);
 
+	/* disconnect close_needed active servers if server_fast_close is set */
+	if (cf_server_fast_close) {
+		statlist_for_each_safe(item, &pool->active_server_list, tmp) {
+			server = container_of(item, PgSocket, head);
+			Assert(server->state == SV_ACTIVE);
+			if (server->ready && server->close_needed)
+				disconnect_server(server, true, "database configuration changed");
+		}
+	}
+
 	/* where query got did not get answer in query_timeout */
 	if (cf_query_timeout > 0 || cf_idle_transaction_timeout > 0) {
 		statlist_for_each_safe(item, &pool->active_server_list, tmp) {
@@ -672,4 +730,3 @@ void config_postprocess(void)
 			db->res_pool_size = cf_res_pool_size;
 	}
 }
-
