@@ -169,6 +169,7 @@ static bool another_result(DbConn *db)
 				       db->_arglen, curlen);
 			}
 		}
+		/* fallthrough */
 	case PGRES_COMMAND_OK:
 		PQclear(res);
 		break;
@@ -501,7 +502,7 @@ int main(int argc, char *argv[])
         wsresult = WSAStartup(MAKEWORD(2,0),&wsaData);
         if (wsresult != 0)
         {
-                fatal("Cannot start the network subsystem -%d", wsresult);
+                fatal("cannot start the network subsystem: -%d", wsresult);
         }
 #endif
 	if (throttle_connects < 0 || throttle_queries < 0 || numcon < 0)
@@ -534,5 +535,3 @@ int main(int argc, char *argv[])
 	}
 	return 0;
 }
-
-
