@@ -1,35 +1,37 @@
 #!/bin/sh
 
 fw_drop_port() {
-        echo "fw_drop_port"
+	echo "fw_drop_port"
 	case `uname` in
 	Linux)
 		sudo iptables -A OUTPUT -p tcp --dport $1 -j DROP;;
-	Darwin)
-		sudo ipfw add 100 drop tcp from any to 127.0.0.1 dst-port $1;;
+	Darwin|OpenBSD)
+		echo "block drop out proto tcp from any to 127.0.0.1 port $1" \
+		    | sudo pfctl -a pgbouncer -f -;;
 	*)
 		echo "Unknown OS";;
 	esac
 }
 fw_reject_port() {
-        echo "fw_reject_port"
+	echo "fw_reject_port"
 	case `uname` in
 	Linux)
 		sudo iptables -A OUTPUT -p tcp --dport $1 -j REJECT --reject-with tcp-reset;;
-	Darwin)
-		sudo ipfw add 100 reset tcp from any to 127.0.0.1 dst-port $1;;
+	Darwin|OpenBSD)
+		echo "block return-rst out proto tcp from any to 127.0.0.1 port $1" \
+		    | sudo pfctl -a pgbouncer -f -;;
 	*)
 		echo "Unknown OS";;
 	esac
 }
 
 fw_reset() {
-        echo "fw_reset"
+	echo "fw_reset"
 	case `uname` in
 	Linux)
 		sudo iptables -F;;
-	Darwin)
-		sudo ipfw del 100;;
+	Darwin|OpenBSD)
+		sudo pfctl -a pgbouncer -F all;;
 	*)
 		echo "Unknown OS"; exit 1;;
 	esac
@@ -50,5 +52,3 @@ while true; do
   fw_reset
   sleep 6
 done
-
-
